@@ -1,5 +1,6 @@
 import json
 import logging
+import platform
 from collections import defaultdict
 from datetime import datetime
 from pathlib import Path
@@ -290,7 +291,6 @@ class GitLibMixin:
     def __createCommit(
         self, targetName: str, msg: str, descendents: list[str], index
     ) -> str:
-
         tree = index.write_tree()
         author = self.__committer if self.__committer else self.defaultCommitter
 
@@ -443,6 +443,9 @@ class GitLibMixin:
             )
 
         self._generateReadme()
+        # Reload the Git _repo attribute. This will drop all references held by
+        # the Repository object and allow for checkout on Windows
+        self.loadGitRepo()
 
         # Walk the commits till we find the previous common point
         checkedLastCommit = next(
