@@ -67,7 +67,9 @@ def _get7z(archivePath: Path, memberPath: Path) -> ArchiveFileContent:
 def _getZip(archivePath: Path, memberPath: Path) -> ArchiveFileContent:
     from zipfile import ZipFile, ZIP_DEFLATED, ZipInfo
 
-    pathStr = str(memberPath)
+    # The zipfile library will handle the translation on Windows and POSIX
+    # and escape \ if needed
+    pathStr = memberPath.as_posix()
 
     with ZipFile(archivePath, "r", ZIP_DEFLATED) as reader:
         info: ZipInfo = reader.getinfo(pathStr)
@@ -83,7 +85,9 @@ def _getZip(archivePath: Path, memberPath: Path) -> ArchiveFileContent:
 def _getTarFile(archivePath: Path, memberPath: Path) -> ArchiveFileContent:
     from tarfile import TarFile, TarInfo
 
-    pathStr = str(memberPath)
+    # The tarfile library will handle the translation on Windows and POSIX
+    # and escape \ if needed
+    pathStr = memberPath.as_posix()
 
     with TarFile.open(archivePath, "r") as reader:
         info: TarInfo = reader.getmember(pathStr)
