@@ -59,30 +59,4 @@ class StepTuple(StorageTuple, metaclass=ABCMeta):
         """
         # This is an abstract kind of method, but we can't have an abstract
         # class because StepTuple() is constructed to send to the UI
-        raise NotImplementedError()
-
-    def makeCommentHtml(self, topHeaderNum: int = 1):
-        html = markdown.markdown(
-            self.comment,
-            extensions=[
-                "markdown.extensions.tables",
-                "markdown.extensions.fenced_code",
-                "markdown.extensions.sane_lists",
-            ],
-        )
-
-        highestHeader = 6
-        for h in reversed(range(1, 10)):
-            if "<h%s>" % h in html:
-                highestHeader = h
-
-        # If highest header is <
-        headerDelta = topHeaderNum - highestHeader
-        if headerDelta == 0:
-            return html
-
-        for h in reversed(range(1, 10)):
-            html = html.replace("<h%s>" % h, "<h%s>" % (h + headerDelta))
-            html = html.replace("</h%s>" % h, "</h%s>" % (h + headerDelta))
-
-        return html
+        raise NotImplementedError()
\ No newline at end of file
